using System;
using System.Collections.Generic;

public class Program
{
    public static void Main(string[] args)
    {
        // Create a mediator instance
        var mediator = new HomeMediator();

        // Create devices
        var livingRoomThermometer = new ElectroluxThermometer(mediator, "LivingRoom");
        var bedroomThermometer = new ElectroluxThermometer(mediator, "Bedroom");

        var livingRoomLight = new IKE565Col(mediator, "LivingRoom");
        var bedroomLight = new PH500Amb(mediator, "Bedroom");

        var livingRoomThermostat = new PhilipsThermostat(mediator, "LivingRoom");
        var bedroomThermostat = new PhilipsThermostat(mediator, "Bedroom");

        var frontDoorLock = new SamsungLock(mediator, "FrontDoor");
        var backDoorLock = new PhilipsLock(mediator, "Back Door");



        // Register devices with the mediator
        mediator.AddThermometer(livingRoomThermometer);
        mediator.AddThermometer(bedroomThermometer);

        mediator.AddLight(livingRoomLight);
        mediator.AddLight(bedroomLight);

        mediator.AddThermostat(livingRoomThermostat);
        mediator.AddThermostat(bedroomThermostat);

        mediator.AddLock(frontDoorLock);
        mediator.AddLock(backDoorLock);

        // Test temp change
        Console.WriteLine("Simulating temperature change in Living Room...");
        Console.WriteLine("Expecting lights and thermometers in the living room to react");
        livingRoomThermometer.SimualteTemperatureChange(40);

        Console.WriteLine();
        Console.WriteLine();

        // // Test what heppens when we lock the door
        Console.WriteLine("Locking the front door...");
        Console.WriteLine("Expecting all doors to lock because we are looking front door");
        frontDoorLock.Locks();

    }
}