public class HomeMediator : ISmartHomeMediator
{
    private List<Light> _lights = new();
    private List<Lock> _locks = new();
    private List<Thermostat> _thermostats = new();
    private List<Thermometer> _thermometers = new();
    //This mediator allows for adding Devices at runtime.



    //This is the notify method the smart devices will use to notify the mediator about events
    public void Notify(SmartDevice sender, string eventMessage)
    {
        if (sender is Lock)
        {
            ReactOnLock(sender, eventMessage);
        }
        else if (sender is Thermometer)
        {
            ReactOnThermometer(sender, eventMessage);
        }
    }

    public void AddLight(Light light)
    {
        _lights.Add(light);
    }

    public void AddLock(Lock lockDevice)
    {
        _locks.Add(lockDevice);
    }

    public void AddThermostat(Thermostat thermostat)
    {
        _thermostats.Add(thermostat);
    }

    public void AddThermometer(Thermometer thermometer)
    {
        _thermometers.Add(thermometer);
    }


    ///This method will be called when the lock is locked or unlocked, this is the handler method for lock events.
    public void ReactOnLock(SmartDevice sender, string eventMessage)
    {

        if (eventMessage == "Locked" && sender.Location == "FrontDoor")
        {
            foreach (var item in _locks)
            {
                if (item.Location != "FrontDoor") item.Locks();
            }
        }
    }


    ///This method will be called when the thermometer is changed, this is the handler method for thermometer events.
    public void ReactOnThermometer(SmartDevice sender, string eventMessage)
    {
        if (eventMessage == "TemperatureChanged")
        {
            var location = sender.Location;
            var temperature = (sender as Thermometer).GetTemperature();

            var kelvin = temperature + 273.15 * 200;

            foreach (var light in _lights)
            {
                if (light.Location == location)
                {
                    light.ChangeColor(kelvin.ToString());
                }
            }
            foreach (var thermostat in _thermostats)
            {
                if (thermostat.Location == location)
                {
                    if (temperature > 20)
                    {
                        thermostat.DecreaseTemperature(20);
                    }
                    else if (temperature < 20)
                    {
                        thermostat.IncreaseTemperature(20);
                    }
                }
            }
        }
    }

    //This is a method that is called on the mediator to turn off all lights in the house.
    public void TurnOffAllLights()
    {
        foreach (var light in _lights)
        {
            light.TurnOff();
        }
    }

    //This is a method that is called on the mediator to turn on all lights in the house.
    public void TurnOnAllLights()
    {
        foreach (var light in _lights)
        {
            light.TurnOn();
        }
    }

}